## 指数基本信息

接口：index_basic，可以通过数据工具调试和查看数据。

描述：获取指数基础信息。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 指数代码 |
| name | str | N | 指数简称 |
| market | str | N | 交易所或服务商(默认SSE) |
| publisher | str | N | 发布商 |
| category | str | N | 指数类别 |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| ts_code | str | TS代码 |
| name | str | 简称 |
| fullname | str | 指数全称 |
| market | str | 市场 |
| publisher | str | 发布方 |
| index_type | str | 指数风格 |
| category | str | 指数类别 |
| base_date | str | 基期 |
| base_point | float | 基点 |
| list_date | str | 发布日期 |
| weight_rule | str | 加权方式 |
| desc | str | 描述 |
| exp_date | str | 终止日期 |

市场说明(market)

| 市场代码 | 说明 |
| --- | --- |
| MSCI | MSCI指数 |
| CSI | 中证指数 |
| SSE | 上交所指数 |
| SZSE | 深交所指数 |
| CICC | 中金指数 |
| SW | 申万指数 |
| OTH | 其他指数 |

指数列表

- 主题指数
- 规模指数
- 策略指数
- 风格指数
- 综合指数
- 成长指数
- 价值指数
- 有色指数
- 化工指数
- 能源指数
- 其他指数
- 外汇指数
- 基金指数
- 商品指数
- 债券指数
- 行业指数
- 贵金属指数
- 农副产品指数
- 软商品指数
- 油脂油料指数
- 非金属建材指数
- 煤焦钢矿指数
- 谷物指数

接口使用

```python
pro = ts.pro_api()

df = pro.index_basic(market='SW')
```

数据样例

```python
ts_code    name              market     publisher   category     base_date  base_point  \
5    801010.SI    农林牧渔             SW      申万   一级行业指数  19991230      1000.0   
```